@@ -1,7 +1,7 @@
  /******************************************************************
  *	              A.L.E.C's LMS Daemon
  *******************************************************************
- *  LMS version 1.3.0 Apophis
+ *  LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- * $Id: almsd.c,v 1.17 2004/02/18 12:49:22 lukasz Exp $ 
+ * $Id: almsd.c,v 1.18 2004/08/30 19:00:05 alec Exp $ 
  */
 
 #include <unistd.h>
@@ -76,7 +76,9 @@ int main(int argc, char *argv[])
     	}
     
     	// start logging 
+#ifdef DEBUG1
     	syslog(LOG_INFO, "A.L.E.C's LMS Daemon started.");
+#endif
     
     	// initialize global structure 
     	g = (GLOBAL *) realloc(NULL,sizeof(GLOBAL));
@@ -172,7 +174,9 @@ int main(int argc, char *argv[])
 		}
 
 		if( reload ) { // **********************************************
+#ifdef DEBUG1
 	    		syslog(LOG_INFO, "Reload signal detected, calling modules...");
+#endif
 	    
 	    		// read configuration from lms.ini
 	    		ini = iniparser_load(ini_file);
