@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,52 +21,49 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: checkip.php,v 1.15 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: checkip.php,v 1.16 2004/09/01 06:12:48 alec Exp $
  */
 
 // Sprawdzenie czy poczenie z dozwolonego IP.
 
-if($_CONFIG[phpui][allow_from])
+if($_CONFIG['phpui']['allow_from'])
 {
 	// usumy prefix ipv6 jak jest
 	
-	$ipaddr = str_replace("::ffff:","",$_SERVER[REMOTE_ADDR]);
+	$ipaddr = str_replace('::ffff:','',$_SERVER['REMOTE_ADDR']);
 
-	$allowedlist = explode(",",$_CONFIG[phpui][allow_from]);
+	$allowedlist = explode(',',$_CONFIG['phpui']['allow_from']);
 
 	foreach($allowedlist as $value)
 	{
-		list($net,$mask) = split("/",$value);
+		list($net,$mask) = split('/',$value);
 		$net=trim($net);
 		$mask=trim($mask);
-		if($mask == "")
-			$mask = "32";
+		if($mask == '')
+			$mask = '32';
 		if($mask >= 0 || $mask <= 32)
 			$mask = prefix2mask($mask);
 	
 		if(isipinstrict($ipaddr,$net,$mask))
 			$isin = TRUE;
-
 	}
 
 	if(!$isin)
 	{
-		header("HTTP/1.1 403 Forbidden");
+		header('HTTP/1.1 403 Forbidden');
 		echo '<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
 		<HTML><HEAD>
 		<TITLE>403 Forbidden</TITLE>
 		</HEAD><BODY>
 		<H1>Forbidden</H1>
-		You don\'t have permission to access '.$_SERVER[REQUEST_URI].'
+		You don\'t have permission to access '.$_SERVER['REQUEST_URI'].'
 		on this server.<P>
 		<HR>
-		'.$_SERVER[SERVER_SIGNATURE].'
+		'.$_SERVER['SERVER_SIGNATURE'].'
 		</BODY></HTML>
 		';
 		exit(0);
 	}
-		
-
 }
 
 ?>
