@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.4 Terok
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: unstrip.php,v 1.16 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: unstrip.php,v 1.17 2004/09/01 06:12:48 alec Exp $
  */
 
 function r_stripslashes($string)
@@ -45,6 +45,6 @@ function r_stripslashes($string)
 if(get_magic_quotes_gpc())
 	$_POST = r_stripslashes($_POST);
 
-$_SERVER[REMOTE_ADDR] = str_replace("::ffff:","",$_SERVER[REMOTE_ADDR]);
+$_SERVER['REMOTE_ADDR'] = str_replace("::ffff:","",$_SERVER['REMOTE_ADDR']);
 
 ?>
