@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,26 +21,25 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: admininfo.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: admininfo.php,v 1.24 2004/03/11 17:24:21 lukasz Exp $
  */
 
-if(!$LMS->AdminExists($_GET[id]))
+if(!$LMS->AdminExists($_GET['id']))
 {
 	header("Location: ?m=adminlist");
 	die;
 }
 
-$layout[pagetitle]="Informacje o administratorze: ".$LMS->GetAdminName($_GET[id]);
-$admininfo=$LMS->GetAdminInfo($_GET[id]);
+$layout['pagetitle'] = "Informacje o administratorze: ".$LMS->GetAdminName($_GET['id']);
+$admininfo=$LMS->GetAdminInfo($_GET['id']);
 
-$rights = $LMS->GetAdminRights($_GET[id]);
+$rights = $LMS->GetAdminRights($_GET['id']);
 foreach($rights as $right)
-	if($access[table][$right][name])
-		$accesslist[] = $access[table][$right][name];
+	if($access['table'][$right]['name'])
+		$accesslist[] = $access['table'][$right]['name'];
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("admininfo",$admininfo);
-$SMARTY->assign("accesslist",$accesslist);
-$SMARTY->display("admininfo.html");
+$SMARTY->assign('admininfo',$admininfo);
+$SMARTY->assign('accesslist',$accesslist);
+$SMARTY->display('admininfo.html');
 
 ?>
\ No newline at end of file
