@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.0 Apophis
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,13 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: adminlist.php,v 1.16 2004/02/18 12:49:23 lukasz Exp $
+ *  $Id: adminlist.php,v 1.18 2004/03/11 17:24:21 lukasz Exp $
  */
 
-$layout[pagetitle] = "Administratorzy";
+$layout['pagetitle'] = "Administratorzy";
 
-$SMARTY->assign("layout",$layout);
-$SMARTY->assign("adminslist",$LMS->GetAdminList());
-$SMARTY->display("adminlist.html");
+$SMARTY->assign('adminslist',$LMS->GetAdminList());
+$SMARTY->display('adminlist.html');
 
 ?>
\ No newline at end of file
