@@ -1,7 +1,7 @@
 <?php
 
 /*
- * LMS version 1.3.1 Maybourne
+ * LMS version 1.3.6 Osiris
  *
  *  (C) Copyright 2001-2004 LMS Developers
  *
@@ -21,11 +21,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodesearch.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
+ *  $Id: nodesearch.php,v 1.22 2004/03/11 17:24:22 lukasz Exp $
  */
 
 $layout['pagetitle'] = "Wyszukiwanie komputerw";
-$SMARTY->assign('layout',$layout);
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
 
